unit Childwin;

interface

uses WinTypes, WinProcs, Classes, Graphics, Forms, Controls, StdCtrls,
     ExtMemo, SysUtils;

type
  TMDIChild = class(TForm)
    EditMemo: TExtMemo;
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure FormActivate(Sender: TObject);
    procedure EditMemoPosChange(Sender: TObject; Col, Row: Integer);
    procedure EditMemoModeChange(Sender: TObject; InsertMode: Boolean);
    procedure EditMemoKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure FormResize(Sender: TObject);
    procedure EditMemoIndentChange(Sender: TObject; AutoIndent: Boolean);
    procedure EditMemoLeftMarginChange(Sender: TObject; Margin: Integer);
    procedure EditMemoTabStopChange(Sender: TObject; TTabStop: Integer);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

implementation

uses
  Main;

{$R *.DFM}

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMDIChild.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  Action := caFree;

  {Erase the panels}
  MainForm.PosPanel.Caption:= '';
  MainForm.ModePanel.Caption:= '';
  MainForm.IndentPanel.Caption:= '';
  MainForm.MarginCombo.Text:= '';
  MainForm.TabCombo.Text:= '';
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMDIChild.FormActivate(Sender: TObject);
begin
  {Get caret position and input mode}
  EditMemo.GetMemoStatus;

  MainForm.MarginCombo.Text:=  IntToStr(EditMemo.LeftMargin div FontWidth);
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMDIChild.EditMemoPosChange(Sender: TObject; Col, Row: Integer);
begin
  {Write the caret position in the position panel}
  MainForm.PosPanel.Caption:= IntToStr(Row) + ' : ' + IntToStr(Col);
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMDIChild.EditMemoModeChange(Sender: TObject;
  InsertMode: Boolean);
begin
  {Is memo in insert mode..}
  if InsertMode then
    {..then write 'Insert'}
    MainForm.ModePanel.Caption:= 'Insert'
  else
    {..otherwise write 'overwrite'}
    MainForm.ModePanel.Caption:= 'Overwrite';
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMDIChild.EditMemoKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  {If the INS-key is pressed}
  if Key = VK_INSERT then
  begin
    {Is memo in insert mode..}
    if EditMemo.InsertMode then
      {..then toggle to overwrite mode}
      EditMemo.InsertMode:= False
    else
      {..otherwise put it in insert mode}
      EditMemo.InsertMode:= True;
  end;
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMDIChild.FormResize(Sender: TObject);
var
  Index: Integer;
  AllMinimized: Boolean;
begin
  AllMinimized:= True;

  {Check if all childs are minimized}
  for Index:= 0 to MainForm.MDIChildCount - 1 do
  begin
    if ((MainForm.MDIChildren[Index] as TMDIChild).WindowState <> wsMinimized) then
      AllMinimized:= False;
  end;

  {Are all childs are minimized..}
  if AllMinimized then
  begin
    {..then erase all panels}
    MainForm.PosPanel.Caption:= '';
    MainForm.ModePanel.Caption:= '';
    MainForm.IndentPanel.Caption:= '';
    MainForm.MarginCombo.Text:= '';
    MainForm.TabCombo.Text:= '';
  end
  else
    {..otherwise get information from the new active child}
    (MainForm.ActiveMDIChild as TMDIChild).EditMemo.GetMemoStatus;
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMDIChild.EditMemoIndentChange(Sender: TObject;
                                         AutoIndent: Boolean);
begin
  {Is memo in auto indentation mode..}
  if AutoIndent then
    {..then write 'Auto Indentation'}
    MainForm.IndentPanel.Caption:= 'Auto Indentation'
  else
    {..otherwise write ''}
    MainForm.IndentPanel.Caption:= '';
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMDIChild.EditMemoLeftMarginChange(Sender: TObject;
  Margin: Integer);
begin
  MainForm.MarginCombo.Text:= IntToStr(EditMemo.LeftMargin div FontWidth);
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMDIChild.EditMemoTabStopChange(Sender: TObject;
  TTabStop: Integer);
begin
  MainForm.TabCombo.Text:= IntToStr(EditMemo.TabStop);
end;

end.
