unit Main;

interface

uses WinTypes, WinProcs, SysUtils, Classes, Graphics, Forms, Controls, Menus,
  StdCtrls, Dialogs, Buttons, Messages, ExtCtrls;

type
  TMainForm = class(TForm)
    MainMenu1: TMainMenu;
    Panel1: TPanel;
    StatusLine: TPanel;
    File1: TMenuItem;
    FileNewItem: TMenuItem;
    PosPanel: TPanel;
    FileCloseItem: TMenuItem;
    Window1: TMenuItem;
    N1: TMenuItem;
    FileExitItem: TMenuItem;
    WindowCascadeItem: TMenuItem;
    WindowTileItem: TMenuItem;
    WindowArrangeItem: TMenuItem;
    WindowMinimizeItem: TMenuItem;
    SpeedPanel: TPanel;
    NewBtn: TSpeedButton;
    ExitBtn: TSpeedButton;
    ModePanel: TPanel;
    IndentPanel: TPanel;
    IndentButton: TButton;
    MarginCombo: TComboBox;
    Label1: TLabel;
    Label2: TLabel;
    TabCombo: TComboBox;
    procedure FormCreate(Sender: TObject);
    procedure FileNewItemClick(Sender: TObject);
    procedure WindowCascadeItemClick(Sender: TObject);
    procedure UpdateMenuItems(Sender: TObject);
    procedure WindowTileItemClick(Sender: TObject);
    procedure WindowArrangeItemClick(Sender: TObject);
    procedure FileCloseItemClick(Sender: TObject);
    procedure FileExitItemClick(Sender: TObject);
    procedure WindowMinimizeItemClick(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure IndentButtonClick(Sender: TObject);
    procedure MarginComboChange(Sender: TObject);
    procedure TabComboChange(Sender: TObject);
  private
    { Private declarations }
    procedure CreateMDIChild(const Name: string);
    procedure ShowHint(Sender: TObject);
  public
    { Public declarations }
  end;

var
  MainForm: TMainForm;
  FontWidth: Integer;

implementation

{$R *.DFM}

uses ChildWin;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMainForm.FormCreate(Sender: TObject);
begin
  Application.OnHint := ShowHint;
  Screen.OnActiveFormChange := UpdateMenuItems;

  FontWidth:= 1;

  {Insert margin values in combobox}
  MarginCombo.Items.Add('0');
  MarginCombo.Items.Add('5');
  MarginCombo.Items.Add('10');
  MarginCombo.Items.Add('15');
  MarginCombo.Items.Add('20');

  {Insert tab stop values in combobox}
  TabCombo.Items.Add('0');
  TabCombo.Items.Add('5');
  TabCombo.Items.Add('10');
  TabCombo.Items.Add('15');
  TabCombo.Items.Add('20');
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMainForm.ShowHint(Sender: TObject);
begin
  StatusLine.Caption := Application.Hint;
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMainForm.CreateMDIChild(const Name: string);
var
  Child: TMDIChild;
begin
  { create a new MDI child window }
  Child := TMDIChild.Create(Application);
  Child.EditMemo.Clear;
  Child.Caption := Name;
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMainForm.FileNewItemClick(Sender: TObject);
begin
  CreateMDIChild('NONAME' + IntToStr(MDIChildCount + 1));
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMainForm.FileCloseItemClick(Sender: TObject);
begin
  if ActiveMDIChild <> nil then
    ActiveMDIChild.Close;
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMainForm.FileExitItemClick(Sender: TObject);
begin
  Close;
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMainForm.WindowCascadeItemClick(Sender: TObject);
begin
  Cascade;
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMainForm.WindowTileItemClick(Sender: TObject);
begin
  Tile;
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMainForm.WindowArrangeItemClick(Sender: TObject);
begin
  ArrangeIcons;
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMainForm.WindowMinimizeItemClick(Sender: TObject);
var
  I: Integer;
begin
  {Must be done backwards through the MDIChildren array}
  for I:= MDIChildCount - 1 downto 0 do
    MDIChildren[I].WindowState:= wsMinimized;
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMainForm.UpdateMenuItems(Sender: TObject);
begin
  FileCloseItem.Enabled := MDIChildCount > 0;
  WindowCascadeItem.Enabled := MDIChildCount > 0;
  WindowTileItem.Enabled := MDIChildCount > 0;
  WindowArrangeItem.Enabled := MDIChildCount > 0;
  WindowMinimizeItem.Enabled := MDIChildCount > 0;
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMainForm.FormDestroy(Sender: TObject);
begin
  Screen.OnActiveFormChange := nil;
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMainForm.IndentButtonClick(Sender: TObject);
begin
  if (MDIChildCount <> 0) then
  begin
    if ((ActiveMDIChild as TMDIChild).EditMemo.AutoIndent = True) then
      (ActiveMDIChild as TMDIChild).EditMemo.AutoIndent:= False
    else
      (ActiveMDIChild as TMDIChild).EditMemo.AutoIndent:= True;
  end;
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMainForm.MarginComboChange(Sender: TObject);
begin
  if (MDIChildCount <> 0) then
  begin
    {Calculate font width}
    Canvas.Font.Name:= (ActiveMDIChild as TMDIChild).EditMemo.Font.Name;
    Canvas.Font.Size:= (ActiveMDIChild as TMDIChild).EditMemo.Font.Size;
    FontWidth:= Canvas.TextWidth('i');

    {Set new margin}
    (ActiveMDIChild as TMDIChild).EditMemo.LeftMargin:=
                                          StrToInt(MarginCombo.Text) * FontWidth;
    SendMessage((ActiveMDIChild as TMDIChild).EditMemo.Handle, WM_SIZE, 0, 0);
  end;
end;

{**********************************************************}
{* Name :                                                 *}
{* Description :                                          *}
{**********************************************************}

procedure TMainForm.TabComboChange(Sender: TObject);
begin
  if (MDIChildCount <> 0) then
  begin
    {Set new tab stop}
    (ActiveMDIChild as TMDIChild).EditMemo.TabStop:=
                                          StrToInt(TabCombo.Text);
  end;
end;

end.
